@@ -9,8 +9,11 @@ use AsyncAws\CloudFormation\CloudFormationClient;
 use AsyncAws\CloudFront\CloudFrontClient;
 use AsyncAws\CloudWatch\CloudWatchClient;
 use AsyncAws\CloudWatchLogs\CloudWatchLogsClient;
+use AsyncAws\CodeBuild\CodeBuildClient;
+use AsyncAws\CodeCommit\CodeCommitClient;
 use AsyncAws\CodeDeploy\CodeDeployClient;
 use AsyncAws\CognitoIdentityProvider\CognitoIdentityProviderClient;
+use AsyncAws\Comprehend\ComprehendClient;
 use AsyncAws\Core\Credentials\CacheProvider;
 use AsyncAws\Core\Credentials\ChainProvider;
 use AsyncAws\Core\Credentials\CredentialProvider;
@@ -23,7 +26,10 @@ use AsyncAws\ElastiCache\ElastiCacheClient;
 use AsyncAws\EventBridge\EventBridgeClient;
 use AsyncAws\Firehose\FirehoseClient;
 use AsyncAws\Iam\IamClient;
+use AsyncAws\Iot\IotClient;
+use AsyncAws\IotData\IotDataClient;
 use AsyncAws\Kinesis\KinesisClient;
+use AsyncAws\Kms\KmsClient;
 use AsyncAws\Lambda\LambdaClient;
 use AsyncAws\RdsDataService\RdsDataServiceClient;
 use AsyncAws\Rekognition\RekognitionClient;
@@ -35,6 +41,9 @@ use AsyncAws\Sns\SnsClient;
 use AsyncAws\Sqs\SqsClient;
 use AsyncAws\Ssm\SsmClient;
 use AsyncAws\StepFunctions\StepFunctionsClient;
+use AsyncAws\TimestreamQuery\TimestreamQueryClient;
+use AsyncAws\TimestreamWrite\TimestreamWriteClient;
+use AsyncAws\Translate\TranslateClient;
 use AsyncAws\XRay\XRayClient;
 use Psr\Log\LoggerInterface;
 use Psr\Log\NullLogger;
@@ -155,6 +164,32 @@ class AwsClientFactory
         return $this->serviceCache[__METHOD__];
     }
 
+    public function codeBuild(): CodeBuildClient
+    {
+        if (!class_exists(CodeBuildClient::class)) {
+            throw MissingDependency::create('async-aws/code-build', 'CodeBuild');
+        }
+
+        if (!isset($this->serviceCache[__METHOD__])) {
+            $this->serviceCache[__METHOD__] = new CodeBuildClient($this->configuration, $this->credentialProvider, $this->httpClient, $this->logger);
+        }
+
+        return $this->serviceCache[__METHOD__];
+    }
+
+    public function codeCommit(): CodeCommitClient
+    {
+        if (!class_exists(CodeCommitClient::class)) {
+            throw MissingDependency::create('async-aws/code-commit', 'CodeCommit');
+        }
+
+        if (!isset($this->serviceCache[__METHOD__])) {
+            $this->serviceCache[__METHOD__] = new CodeCommitClient($this->configuration, $this->credentialProvider, $this->httpClient, $this->logger);
+        }
+
+        return $this->serviceCache[__METHOD__];
+    }
+
     public function codeDeploy(): CodeDeployClient
     {
         if (!class_exists(CodeDeployClient::class)) {
@@ -168,6 +203,19 @@ class AwsClientFactory
         return $this->serviceCache[__METHOD__];
     }
 
+    public function comprehend(): ComprehendClient
+    {
+        if (!class_exists(ComprehendClient::class)) {
+            throw MissingDependency::create('async-aws/comprehend', 'ComprehendClient');
+        }
+
+        if (!isset($this->serviceCache[__METHOD__])) {
+            $this->serviceCache[__METHOD__] = new ComprehendClient($this->configuration, $this->credentialProvider, $this->httpClient, $this->logger);
+        }
+
+        return $this->serviceCache[__METHOD__];
+    }
+
     public function dynamoDb(): DynamoDbClient
     {
         if (!class_exists(DynamoDbClient::class)) {
@@ -246,6 +294,32 @@ class AwsClientFactory
         return $this->serviceCache[__METHOD__];
     }
 
+    public function iot(): IotClient
+    {
+        if (!class_exists(IotClient::class)) {
+            throw MissingDependency::create('async-aws/iot', 'Iot');
+        }
+
+        if (!isset($this->serviceCache[__METHOD__])) {
+            $this->serviceCache[__METHOD__] = new IotClient($this->configuration, $this->credentialProvider, $this->httpClient, $this->logger);
+        }
+
+        return $this->serviceCache[__METHOD__];
+    }
+
+    public function iotData(): IotDataClient
+    {
+        if (!class_exists(IotDataClient::class)) {
+            throw MissingDependency::create('async-aws/iot-data', 'IotData');
+        }
+
+        if (!isset($this->serviceCache[__METHOD__])) {
+            $this->serviceCache[__METHOD__] = new IotDataClient($this->configuration, $this->credentialProvider, $this->httpClient, $this->logger);
+        }
+
+        return $this->serviceCache[__METHOD__];
+    }
+
     public function kinesis(): KinesisClient
     {
         if (!class_exists(KinesisClient::class)) {
@@ -259,6 +333,19 @@ class AwsClientFactory
         return $this->serviceCache[__METHOD__];
     }
 
+    public function kms(): KmsClient
+    {
+        if (!class_exists(KmsClient::class)) {
+            throw MissingDependency::create('aws/kms', 'Kms');
+        }
+
+        if (!isset($this->serviceCache[__METHOD__])) {
+            $this->serviceCache[__METHOD__] = new KmsClient($this->configuration, $this->credentialProvider, $this->httpClient, $this->logger);
+        }
+
+        return $this->serviceCache[__METHOD__];
+    }
+
     public function lambda(): LambdaClient
     {
         if (!class_exists(LambdaClient::class)) {
@@ -411,6 +498,45 @@ class AwsClientFactory
         return $this->serviceCache[__METHOD__];
     }
 
+    public function timestreamQuery(): TimestreamQueryClient
+    {
+        if (!class_exists(TimestreamQueryClient::class)) {
+            throw MissingDependency::create('async-aws/timestream-query', 'TimestreamQuery');
+        }
+
+        if (!isset($this->serviceCache[__METHOD__])) {
+            $this->serviceCache[__METHOD__] = new TimestreamQueryClient($this->configuration, $this->credentialProvider, $this->httpClient, $this->logger);
+        }
+
+        return $this->serviceCache[__METHOD__];
+    }
+
+    public function timestreamWrite(): TimestreamWriteClient
+    {
+        if (!class_exists(TimestreamWriteClient::class)) {
+            throw MissingDependency::create('async-aws/timestream-write', 'TimestreamWrite');
+        }
+
+        if (!isset($this->serviceCache[__METHOD__])) {
+            $this->serviceCache[__METHOD__] = new TimestreamWriteClient($this->configuration, $this->credentialProvider, $this->httpClient, $this->logger);
+        }
+
+        return $this->serviceCache[__METHOD__];
+    }
+
+    public function translate(): TranslateClient
+    {
+        if (!class_exists(TranslateClient::class)) {
+            throw MissingDependency::create('async-aws/translate', 'Translate');
+        }
+
+        if (!isset($this->serviceCache[__METHOD__])) {
+            $this->serviceCache[__METHOD__] = new TranslateClient($this->configuration, $this->credentialProvider, $this->httpClient, $this->logger);
+        }
+
+        return $this->serviceCache[__METHOD__];
+    }
+
     public function xRay(): XRayClient
     {
         if (!class_exists(XRayClient::class)) {
